use-oci-hook
use-oci-hook provides OCI runtime hook primitives for lifecycle phases, paths, args, env, and timeout metadata.
It is part of the use-oci RustUse workspace for small, focused OCI primitive crates. It does not perform network calls, shell out to runtimes, implement a registry client, or build container images.
License
Licensed under either of the following, at your option:
- Apache License, Version 2.0
- MIT license
Structs
- HookArg
- HookEnv
- Hook
Path - Hook
Timeout Seconds - Hook timeout in seconds.
- OciHook
- OCI hook metadata. This type does not execute hooks.